@@ -21,7 +21,6 @@ from .functions import (
 from .listeners import coercion_listener
 from .merge import merge, Merger
 from .generic import generic_relationship
-from .primitives import NumberRange, NumberRangeException
 from .proxy_dict import ProxyDict, proxy_dict
 from .types import (
     ArrowType,
@@ -33,6 +32,7 @@ from .types import (
     EmailType,
     instrumented_list,
     InstrumentedList,
+    IntRangeType,
     IPAddressType,
     JSONType,
     LocaleType,
@@ -40,17 +40,20 @@ from .types import (
     PasswordType,
     PhoneNumber,
     PhoneNumberType,
-    NumberRangeRawType,
-    NumberRangeType,
     ScalarListType,
     ScalarListException,
     TimezoneType,
     TSVectorType,
+    URLType,
     UUIDType,
+    INT4RANGE,
+    INT8RANGE,
+    DATERANGE,
+    NUMRANGE,
 )
 
 
-__version__ = '0.22.1'
+__version__ = '0.23.0'
 
 
 __all__ = (
@@ -87,10 +90,7 @@ __all__ = (
     JSONType,
     LocaleType,
     Merger,
-    NumberRange,
-    NumberRangeException,
-    NumberRangeRawType,
-    NumberRangeType,
+    IntRangeType,
     Password,
     PasswordType,
     PhoneNumber,
@@ -100,8 +100,13 @@ __all__ = (
     ScalarListType,
     TimezoneType,
     TSVectorType,
+    URLType,
     UUIDType,
     database_exists,
     create_database,
-    drop_database
+    drop_database,
+    INT4RANGE,
+    INT8RANGE,
+    DATERANGE,
+    NUMRANGE,
 )
